import QtQuick 1.0

/**
 * Show an LED clock.
 *
 * @author Copyright (c) Andrew Flegg 2011. Released under the Artistic Licence.
 */
Rectangle {
    id: clock
    property bool active: true
    property bool dimmed: false

    anchors.fill: parent
    color: "black"

    Item {
        id: values

        property int    block_width: 204
        property double separator_width: 37
        property double padding_fraction: 0.5 - (4.0 * block_width + separator_width) / (854.0 * 2)
        property double scale: parent.width / (separator_width + (4.0 + 2 * padding_fraction) * block_width)
        property double digit_width: block_width * scale
    }


    LED {
        id: digit1
        value: '0'
        x: values.padding_fraction * values.block_width * scale
    }

    LED {
        id: digit2
        value: '0'
        x: digit1.x + digit1.width
    }

    LED {
        id: separator
        width: values.separator_width * values.scale
        value: 'sep'
        x: digit2.x + digit2.width
    }

    LED {
        id: digit3
        value: '0'
        x: separator.x + separator.width
    }

    LED {
        id: digit4
        value: '0'
        x: digit3.x + digit3.width
    }

    Rectangle {
        id: dimmingRectangle
        anchors.fill: parent
        color: "black"
        opacity: 0

        states {
            State {
                name: "dim"
                when: clock.dimmed
                PropertyChanges { target: dimmingRectangle; opacity: 0.66 }
            }
        }
    }

    function redraw() {
        var time = new Date()
        var hours   = time.getHours()
        var minutes = time.getMinutes()

        digit1.value = Math.floor(hours / 10)
        digit2.value = hours % 10
        digit3.value = Math.floor(minutes / 10)
        digit4.value = minutes % 10

        timer.interval = (60 - new Date().getSeconds()) * 1000
    }

    Component.onCompleted: redraw()
    onActiveChanged: if (active) redraw()
    onDimmedChanged: backlight.toggle()

    Timer {
        id: timer
        interval: 60000
        repeat: true
        onTriggered : clock.redraw()
        running: clock.active
    }
}
